@@ -20,6 +20,6 @@ def verified_project():
     project = CreateProject.objects.get(project_key=project_key)
     user = User.objects.get(id=user_id)
 
-    if user == project.user:
+    if user == project.User:
         return True
     return False
\ No newline at end of file
